@@ -1,5 +1,5 @@
 #!/bin/bash
-# Copyright 1999-2020 Gentoo Authors
+# Copyright 1999-2021 Gentoo Authors
 # Distributed under the terms of the GNU General Public License v2
 
 if ___eapi_has_DESTTREE_INSDESTTREE; then
@@ -21,7 +21,7 @@ export PORTAGE_DOCOMPRESS_SIZE_LIMIT="128"
 declare -a PORTAGE_DOCOMPRESS=( /usr/share/{doc,info,man} )
 declare -a PORTAGE_DOCOMPRESS_SKIP=( /usr/share/doc/${PF}/html )
 declare -a PORTAGE_DOSTRIP=( / )
-has strip ${RESTRICT} && PORTAGE_DOSTRIP=()
+has strip ${PORTAGE_RESTRICT} && PORTAGE_DOSTRIP=()
 declare -a PORTAGE_DOSTRIP_SKIP=()
 
 into() {
@@ -190,13 +190,19 @@ dostrip() {
 }
 
 useq() {
+	___eapi_has_useq || die "'${FUNCNAME}' banned in EAPI ${EAPI}"
+
 	eqawarn "QA Notice: The 'useq' function is deprecated (replaced by 'use')"
 	use ${1}
 }
 
 usev() {
+	local nargs=1
+	___eapi_usev_has_second_arg && nargs=2
+	[[ ${#} -gt ${nargs} ]] && die "usev takes at most ${nargs} arguments"
+
 	if use ${1}; then
-		echo "${1#!}"
+		echo "${2:-${1#!}}"
 		return 0
 	fi
 	return 1
@@ -427,11 +433,15 @@ unpack() {
 				__unpack_tar "${PORTAGE_BUNZIP2_COMMAND:-${PORTAGE_BZIP2_COMMAND} -d}"
 				;;
 			7z)
-				local my_output
-				my_output="$(7z x -y "${srcdir}${x}")"
-				if [ $? -ne 0 ]; then
-					echo "${my_output}" >&2
-					die "$myfail"
+				if ___eapi_unpack_supports_7z; then
+					local my_output
+					my_output="$(7z x -y "${srcdir}${x}")"
+					if [ $? -ne 0 ]; then
+						echo "${my_output}" >&2
+						die "$myfail"
+					fi
+				else
+					__vecho "unpack ${x}: file format not recognized. Ignoring."
 				fi
 				;;
 			rar)
@@ -441,7 +451,11 @@ unpack() {
 						"suffix '${suffix}' which is unofficially supported" \
 						"with EAPI '${EAPI}'. Instead use 'rar' or 'RAR'."
 				fi
-				unrar x -idq -o+ "${srcdir}${x}" || die "$myfail"
+				if ___eapi_unpack_supports_rar; then
+					unrar x -idq -o+ "${srcdir}${x}" || die "$myfail"
+				else
+					__vecho "unpack ${x}: file format not recognized. Ignoring."
+				fi
 				;;
 			lha|lzh)
 				if ___eapi_unpack_is_case_sensitive && \
@@ -451,7 +465,11 @@ unpack() {
 						"with EAPI '${EAPI}'." \
 						"Instead use 'LHA', 'LHa', 'lha', or 'lzh'."
 				fi
-				lha xfq "${srcdir}${x}" || die "$myfail"
+				if ___eapi_unpack_supports_lha; then
+					lha xfq "${srcdir}${x}" || die "$myfail"
+				else
+					__vecho "unpack ${x}: file format not recognized. Ignoring."
+				fi
 				;;
 			a)
 				if ___eapi_unpack_is_case_sensitive && \
@@ -603,6 +621,12 @@ econf() {
 		if ___eapi_econf_passes_--disable-dependency-tracking || ___eapi_econf_passes_--disable-silent-rules || ___eapi_econf_passes_--docdir_and_--htmldir || ___eapi_econf_passes_--with-sysroot; then
 			local conf_help=$("${ECONF_SOURCE}/configure" --help 2>/dev/null)
 
+			if ___eapi_econf_passes_--datarootdir; then
+				if [[ ${conf_help} == *--datarootdir* ]]; then
+					conf_args+=( --datarootdir="${EPREFIX}"/usr/share )
+				fi
+			fi
+
 			if ___eapi_econf_passes_--disable-dependency-tracking; then
 				if [[ ${conf_help} == *--disable-dependency-tracking* ]]; then
 					conf_args+=( --disable-dependency-tracking )
@@ -615,6 +639,13 @@ econf() {
 				fi
 			fi
 
+			if ___eapi_econf_passes_--disable-static; then
+				if [[ ${conf_help} == *--disable-static* || \
+						${conf_help} == *--enable-static* ]]; then
+					conf_args+=( --disable-static )
+				fi
+			fi
+
 			if ___eapi_econf_passes_--docdir_and_--htmldir; then
 				if [[ ${conf_help} == *--docdir* ]]; then
 					conf_args+=( --docdir="${EPREFIX}"/usr/share/doc/${PF} )
@@ -840,6 +871,17 @@ __eapi6_src_install() {
 	einstalldocs
 }
 
+__eapi8_src_prepare() {
+	local f
+	if ___is_indexed_array_var PATCHES ; then
+		[[ ${#PATCHES[@]} -gt 0 ]] && eapply -- "${PATCHES[@]}"
+	elif [[ -n ${PATCHES} ]]; then
+		eapply -- ${PATCHES}
+	fi
+
+	eapply_user
+}
+
 ___best_version_and_has_version_common() {
 	local atom root root_arg
 	local -a cmd=()
@@ -1097,6 +1139,10 @@ if ___eapi_has_eapply_user; then
 
 		local basedir=${PORTAGE_CONFIGROOT%/}/etc/portage/patches
 
+		local columns=${COLUMNS:-0}
+		[[ ${columns} == 0 ]] && columns=$(set -- $( ( stty size </dev/tty ) 2>/dev/null || echo 24 80 ) ; echo $2)
+		(( columns > 0 )) || (( columns = 80 ))
+
 		local applied d f
 		local -A _eapply_user_patches
 		local prev_shopt=$(shopt -p nullglob)
@@ -1128,6 +1174,11 @@ if ___eapi_has_eapply_user; then
 			while read -r -d '' f; do
 				f=${_eapply_user_patches[${f}]}
 				if [[ -s ${f} ]]; then
+					if [[ -z ${applied} ]]; then
+						einfo "${PORTAGE_COLOR_INFO}$(for ((column = 0; column < ${columns} - 3; column++)); do echo -n =; done)${PORTAGE_COLOR_NORMAL}"
+						einfo "Applying user patches from ${basedir} ..."
+					fi
+
 					eapply "${f}"
 					applied=1
 				fi
@@ -1137,7 +1188,10 @@ if ___eapi_has_eapply_user; then
 
 		${prev_shopt}
 
-		[[ -n ${applied} ]] && ewarn "User patches applied."
+		if [[ -n ${applied} ]]; then
+			einfo "User patches applied."
+			einfo "${PORTAGE_COLOR_INFO}$(for ((column = 0; column < ${columns} - 3; column++)); do echo -n =; done)${PORTAGE_COLOR_NORMAL}"
+		fi
 	}
 fi
 
